'use strict';

const levelup = require('levelup');
const memdown = require('memdown');

const kad = require('kad');
const onion = require('..'); // require('kad-onion');

const node1 = kad({
  contact: { hostname: '', port: 8080 },
  storage: levelup(memdown('onion-test-1')),
  transport: new kad.HTTPTransport()
});

node1.plugin(onion({
  dataDirectory: '/tmp/kad-onion-1', // Set to persist onion hostname
  virtualPort: 80,
  localMapping: '127.0.0.1:8080',
  passthroughLoggingEnabled: true
}));

const node2 = kad({
  contact: { hostname: '', port: 8081 },
  storage: levelup(memdown('onion-test-2')),
  transport: new kad.HTTPTransport()
});

node2.plugin(onion({
  dataDirectory: '/tmp/kad-onion-2', // Set to persist onion hostname
  virtualPort: 80,
  localMapping: '127.0.0.1:8081',
  passthroughLoggingEnabled: true
}));

node1.listen(8080, function() {
  node2.listen(8081, function() {
    node1.logger.info('sending a ping message to node 2');
    node1.ping([node2.identity.toString('hex'), node2.contact], (err) => {
      if (err) {
        node1.logger.error(err.message);
        process.exit(1);
      }
      node1.logger.info('successfully exchanged ping!');
      process.exit();
    });
  });
});

